#
# spec file for package mtd-utils
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mtd-utils
Version:        2.1.2
Release:        1.15
Summary:        Tools for maintaining Memory Technology Devices
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            http://www.linux-mtd.infradead.org/
Source0:        ftp://ftp.infradead.org/pub/mtd-utils/mtd-utils-%{version}.tar.bz2
Source1:        ftp://ftp.infradead.org/pub/mtd-utils/mtd-utils-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)
Supplements:    filesystem(jffs2)
Supplements:    filesystem(ubifs)

%description
This package contains tools for erasing and formatting flash devices,
including JFFS2, M-Systems DiskOnChip devices, etc.

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ubifs-utils/mkfs.ubifs/README
%{_sbindir}/doc_loadbios
%{_sbindir}/docfdisk
%{_sbindir}/flash_erase
%{_sbindir}/flash_eraseall
%{_sbindir}/flash_lock
%{_sbindir}/flash_otp_dump
%{_sbindir}/flash_otp_info
%{_sbindir}/flash_otp_lock
%{_sbindir}/flash_otp_write
%{_sbindir}/flash_unlock
%{_sbindir}/flashcp
%{_sbindir}/ftl_check
%{_sbindir}/ftl_format
%{_sbindir}/jffs2dump
%{_sbindir}/jffs2reader
%{_sbindir}/lsmtd
%{_sbindir}/mkfs.jffs2
%{_sbindir}/mkfs.ubifs
%{_sbindir}/mtd_debug
%{_sbindir}/mtdinfo
%{_sbindir}/mtdpart
%{_sbindir}/nanddump
%{_sbindir}/nandtest
%{_sbindir}/nandwrite
%{_sbindir}/nftl_format
%{_sbindir}/nftldump
%{_sbindir}/recv_image
%{_sbindir}/rfddump
%{_sbindir}/rfdformat
%{_sbindir}/serve_image
%{_sbindir}/sumtool
%{_sbindir}/ubiattach
%{_sbindir}/ubiblock
%{_sbindir}/ubicrc32
%{_sbindir}/ubidetach
%{_sbindir}/ubihealthd
%{_sbindir}/ubiformat
%{_sbindir}/ubimkvol
%{_sbindir}/ubinfo
%{_sbindir}/ubinize
%{_sbindir}/ubirename
%{_sbindir}/ubirmvol
%{_sbindir}/ubirsvol
%{_sbindir}/ubiupdatevol
%{_mandir}/man1/mkfs.jffs2.1%{?ext_man}
%{_mandir}/man8/lsmtd.8%{?ext_man}
%{_mandir}/man8/ubinize.8%{?ext_man}

%changelog
* Thu Nov  5 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.1.2:
  * Features:
    + flashcp: Add option -A/--erase-all
    + mtd-utils: add optional offset parameter to flash_otp_dump
    + ubi-utils: Implement a ubihealthd
    + mkfs.ubifs: Add authentication support
  * Fixes:
    + ubifs-media: Update to Linux-5.3-rc3
    + mtd-utils: Fix return value of ubiformat
    + ubiupdatevol: Prevent null pointer dereference
    + libubigen: remove unnecessary include
    + libubi: remove private kernel header from includes
    + mkfs.ubifs: fscrypt: bail from encrypt_block if gen_essiv_salt fails
    + mkfs.ubifs: abort add_directory if readdir fails
    + mkfs.ubifs: close file descriptor in add_file error path
    + mkfs.ubifs: don't leak copied command line arguments
    + mkfs.ubifs: free derived fscrypt context in add_directory error paths
    + mkfs.ubifs: don't leak hastable iterators
    + mkfs.ubifs: don't leak temporary buffers
    + mkfs.ubifs: propperly cleanup in ALL interpret_table_entry error paths
    + mkfs.jffs2: don't leak temporary buffer if readlink fails
    + libmtd: don't leak temporary buffers
    + ftl_check: don't leak temporary buffers
    + ftl_format: don't leak temporary buffers
    + ubiformat: don't leak file descriptors
    + nanddump: don't leak copied command line arguments
    + mtd_debug: cleanup error handling in flash_to_file
    + jittertest: fix error check for open system call
    + fs-tests: don't leak temporary buffers
    + mtd-utils: Fix printf format specifiers with the wrong type
    + mtd-utils: Fix potential negative arguments passed to close(2)
    + mtd-utils: Fix various TOCTOU issues
    + mtd-utils: Fix some simple cases of uninitialized value reads
    + mtd-utils: Fix wrong argument to sizeof in nanddump
    + mtd-utils: Fix "are we really at EOF" test logic in libubi read_data
    + mtd-utils: Fix potentially unterminated strings
    + mtd-utils: Add checks to code that copies strings into fixed sized buffers
    + mkfs.ubifs: fix broken build if fscrtyp is disabled
* Mon Feb  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.1.1:
  * Features:
  - mkfs.ubifs: Add ZSTD compression
  * Fixes:
    + ubiformat: Dont ignore sequence number CLI option
    + mkfs.ubifs: fix build without openssl
    + mkfs.ubifs: fix regression when trying to store device special files
    + mkfs.ubifs: fix description of favor_lzo
    + unittests/test_lib: Include proper header for _IOC_SIZE
    + unittests/libmtd_test: Include fcntl header
    + unittests: Define the use of _GNU_SOURCE
    + ubinize: Exit with non-zero exit code on error.
    + mtd-tests: nandbiterrs: Fix issue that just insert error at bit 7
    + ubi-tests: ubi_mkvol_request: Fully initialize 'struct ubi_mkvol_request req'
    + ubi-tests: io_read: Filter invalid offset value before 'lseek' in io_read test
    + ubi-tests: mkvol test: Checks return value 'ENOSPC' for 'ubi_mkvol'
    + ubi-tests: fm_param: Replace 'fm_auto' with 'fm_autoconvert'
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.1.0:
  * Features:
    + mkfs.ubifs: Implement support for file system encryption
    + mkfs.ubifs: Implement selinux labelling support
    + ubinize: add support for skipping CRC check of a static volume when opening
    + ubimkvol: add support for skipping CRC check of a static volume when opening
    + Add lsmtd program
  * Fixes:
  - update various kernel headers
    + Instead of doing preprocessor magic, just output off_t as long long
    + fix verification percent display in flashcp
    + mkfs.ubifs: fix double free
    + mkfs.ubifs: Fix xattr nlink value
    + ubinize: avoid to create two UBI_LAYOUT_VOLUME_ID volume
    + common.h: fix prompt function
    + libmtd: don't print an error message for devices without ecc support
    + io_paral: Fix error handling of update_volume()
    + ubimkvol: Initialize req to zero to make sure no flags are set by default
    + libubi: add volume flags to ubi_mkvol_request
    + mkfs.ubifs: add_xattr is not depending on host XATTR support
    + Revert "Return correct error number in ubi_get_vol_info1" which introduced a regression.
    + make sure pkg-config is installed in configure script
    + ubiformat: process command line arguments before handling file arguments
  * Cleanup:
    + ubiformat: remove no-volume-table option
* Mon Jul  9 2018 mpluskal@suse.com
- Update to version 2.0.2:
  * libmtd: Add support to access OOB available size
  * mkfs.ubifs: Allow root entry in device table
  * Fix unit-test header and file paths for out of tree builds
  * Fix unit test mockup for oobavail sysfs file
  * misc-utils: flash_erase: Fix Jffs2 type flash erase problem
  * libmtd_legacy: Fix some function description mismatches
  * mtd-utils: ubifs: fix typo in without_lzo definition
  * mtd: tests: check erase block count in page test
  * mtd: unittests: Stop testing stat() calls
  * mtd: unittests: Decode arg size from ioctl request
  * mtd: unittests: Use proper unsigned long type for ioctl requests
  * mtd: tests: Fix check on ebcnt in nandpagetest
  * ubi-utils: ubicrc32: process command line arguments first
  * nandbiterrs: Fix erroneous counter increment in for loop body
  * jittertest: Use the appropriate versions of abs()
  * Mark or fix switch cases that fall through
  * mkfs.ubifs: ignore EOPNOTSUPP when listing extended attributes
  * misc-utils: initialize "ip" in docfdisk to NULL
  * mkfs.ubifs: Apply squash-uids to the root node
* Mon Aug 28 2017 mpluskal@suse.com
- Update to version 2.0.1:
  * nandbiterrs: Add Erased Pages Bit Flip Test
  * mkfs.ubifs: Add support for symlinks in device table
  * nanddump: Add --skip-bad-blocks-to-start option
  * nandwrite: Add --skip-bad-blocks-to-start option
  * several fixes and internal cleanups
* Tue Feb 21 2017 mpluskal@suse.com
- Update to version 2.0.0:
  * libmissing with stubs for functions not present in libraries
    like musl
  * unittests for libmtd and libubi
  * port most kernel space mtd test modules to userspace
  * mkfs.ubifs: extended attribute support
  * ubinize: Move lengthy help text to a man page
  * nandwrite: Add skip-all-ff-pages option
  * flash_{un,}lock: support for MEMISLOCKED
  * nandtest: support hex/dec/oct for --offset and --length
* Sun Aug 28 2016 mpluskal@suse.com
- Supplement jffs2 and ubifs filesystems
* Fri Apr  1 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Make building more verbose
- Use optflafs for building
* Sat Dec 12 2015 virtuousfox@gmail.com
- Update to version 1.5.2.
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Thu Apr 26 2012 jeffm@suse.com
- %%debug_package no longer required
* Mon May 10 2010 pascal.bleser@opensuse.org
- rewrote spec file
- added libacl support
- created in the filesystems repository
* Wed Feb 11 2009 jblunck@suse.de
- Update to version 1.2.0.
* Wed May  5 2004 dwmw2@infradead.org
- Initial build.
